@@ -25,10 +25,11 @@ from saltfactories.utils import ports
 class MasterFactory(object):
     @staticmethod
     def default_config(
-        root_dir, master_id, default_options=None, config_overrides=None, order_masters=False,
+        root_dir, master_id, config_defaults=None, config_overrides=None, order_masters=False,
     ):
-        if default_options is None:
-            default_options = salt.config.DEFAULT_MASTER_OPTS.copy()
+        if config_defaults is None:
+            config_defaults = salt.config.DEFAULT_MASTER_OPTS.copy()
+            config_defaults.pop("user", None)
 
         conf_dir = root_dir.join("conf").ensure(dir=True)
         conf_file = conf_dir.join("master").strpath
@@ -39,11 +40,7 @@ class MasterFactory(object):
         pillar_tree_root_base = pillar_tree_root.join("base").ensure(dir=True).strpath
         pillar_tree_root_prod = pillar_tree_root.join("prod").ensure(dir=True).strpath
 
-        stop_sending_events_file = conf_dir.join("stop-sending-events-{}".format(master_id)).strpath
-        with salt.utils.files.fopen(stop_sending_events_file, "w") as wfh:
-            wfh.write("")
-
-        _default_options = {
+        _config_defaults = {
             "id": master_id,
             "conf_file": conf_file,
             "root_dir": root_dir.strpath,
@@ -81,11 +78,11 @@ class MasterFactory(object):
             "max_open_files": 10240,
             "pytest-master": {"log": {"prefix": "salt-master({})".format(master_id)},},
         }
-        # Merge in the initial default options with the internal _default_options
-        salt.utils.dictupdate.update(default_options, _default_options, merge_lists=True)
+        # Merge in the initial default options with the internal _config_defaults
+        salt.utils.dictupdate.update(config_defaults, _config_defaults, merge_lists=True)
 
         if config_overrides:
             # Merge in the default options with the master_config_overrides
-            salt.utils.dictupdate.update(default_options, config_overrides, merge_lists=True)
+            salt.utils.dictupdate.update(config_defaults, config_overrides, merge_lists=True)
 
-        return default_options
+        return config_defaults
