@@ -9,6 +9,7 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import copy
 import fnmatch
 import logging
 import threading
@@ -89,7 +90,7 @@ class EventListener(object):
             if not patterns:
                 break
 
-            for received, expire, master_id, tag, data in self.store:
+            for received, expire, master_id, tag, data in copy.copy(self.store):
                 if received < after_time:
                     # Too old, carry on
                     continue
@@ -107,3 +108,21 @@ class EventListener(object):
             )
             return False
         return True
+
+    def get_events(self, patterns, after_time=None):
+        found_patterns = set()
+        patterns = set(patterns)
+        if after_time is None:
+            after_time = time.time()
+        for received, expire, master_id, tag, data in copy.copy(self.store):
+            if received < after_time:
+                # Too old, carry on
+                continue
+            for pattern in set(patterns):
+                _master_id, _pattern = pattern
+                if _master_id != master_id:
+                    continue
+                if fnmatch.fnmatch(tag, _pattern):
+                    log.debug("Found matching pattern: %s", pattern)
+                    found_patterns.add(pattern)
+        return found_patterns
